class BaseError extends Error {
    constructor(message, code) {
        super(message);

        if (Error.captureStackTrace) {
            Error.captureStackTrace(this, BaseError)
        }
        this.name = this.constructor.name;
        this.date = new Date();
        this.code = code;
    }
}

class BadRequest extends BaseError {
    constructor(message) {
        super(message, 400);
    }
}
class Unauthorized extends BaseError {
    constructor(message) {
        super(message, 401);
    }
}
class Forbidden extends BaseError {
    constructor(message) {
        super(message, 403);
    }
}
class NotFound extends BaseError {
    constructor(message) {
        super(message, 404);
    }
}
class Conflict extends BaseError {
    constructor(message) {
        super(message, 409);
    }
}
class FailedDependency extends BaseError {
    constructor(message) {
        super(message, 424);
    }
}

class InternalServerError extends BaseError {
    constructor(message) {
        super(message, 500);
    }
}


module.exports = {
    BadRequest: BadRequest,
    Unauthorized: Unauthorized,
    Forbidden: Forbidden,
    BaseError: BaseError,
    NotFound: NotFound,
    Conflict: Conflict,
    FailedDependency: FailedDependency,
    InternalServerError: InternalServerError
};